# clip-gofer

<p align="center">
<a href="https://pypi.python.org/pypi/clip-gofer">
    <img src="https://img.shields.io/pypi/v/clip-gofer.svg"
        alt = "Release Status">
</a>

<a href="https://github.com/qgofer/clip-gofer/actions">
    <img src="https://github.com/qgofer/clip-gofer/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">
</a>

<a href="https://qgofer.github.io/clip-gofer/">
    <img src="https://img.shields.io/website/https/qgofer.github.io/clip-gofer/index.html.svg?label=docs&down_message=unavailable&up_message=available" alt="Documentation Status">
</a>

<a href="https://pyup.io/repos/github/qgofer/clip-gofer/">
<img src="https://pyup.io/repos/github/qgofer/clip-gofer/shield.svg" alt="Updates">
</a>

</p>

easily search through videos using natural language queries

-   Free software: MIT
-   Documentation: <https://qgofer.github.io/clip-gofer/>

## Features

-   TODO
-   Complete actual functionality for searching through videos :)

## Credits

This package was created with the [ppw](https://zillionare.github.io/python-project-wizard) tool. For more information, please visit the [project page](https://zillionare.github.io/python-project-wizard/).
